Crate bobcat_create

Crate bobcat_create 

Structs

U

Functions

const_estimate_addr_post
Estimate the address of the create2 deployment.
const_estimate_addr_pre
create1_partial
create1_slice
create1_slice_res
create1_unit
create1_vec
create2_partial
create2_post_unit
create2_post_vec
create2_pre_unit
create2_pre_vec
create2_slice
create2_slice_pre_keccak256
create2_slice_res
create2_vec_pre_keccak256
deploy_beacon_proxy
Deploy a bobcat-proxy beacon proxy for the beacon provided.
deploy_beacon_proxy_create2
Deploy a bobcat-proxy beacon proxy for the beacon provided.
deploy_beacon_proxy_create2_endowment
Deploy a bobcat-proxy beacon proxy for the beacon provided.
deploy_beacon_proxy_create2_pre_endowment
Deploy a bobcat-proxy beacon proxy for the beacon provided.
deploy_beacon_proxy_endowment
Deploy a bobcat-proxy beacon proxy for the beacon provided.
deploy_beacon_sel_proxy_sel
Create a proxy that calls the selector on the beacon proxy to figure out how to delegate the calldata to.
deploy_beacon_sel_proxy_sel_create2
Create a proxy that calls the selector on the beacon proxy to figure out how to delegate the calldata to.
deploy_beacon_sel_proxy_sel_create2_endowment
Create a proxy that calls the selector on the beacon proxy to figure out how to delegate the calldata to.
deploy_beacon_sel_proxy_sel_create2_pre
Create a proxy that calls the selector on the beacon proxy to figure out how to delegate the calldata to.
deploy_beacon_sel_proxy_sel_create2_pre_endowment
Create a proxy that calls the selector on the beacon proxy to figure out how to delegate the calldata to.
deploy_beacon_sel_proxy_sel_endowment
Create a proxy that calls the selector on the beacon proxy to figure out how to delegate the calldata to.
deploy_minimal_proxy
Deploy a bobcat-proxy minimal proxy for the implementation address provided.
deploy_minimal_proxy_create2
Deploy a bobcat-proxy minimal proxy for the implementation address provided.
deploy_minimal_proxy_create2_endowment
Deploy a bobcat-proxy minimal proxy for the implementation address provided.
deploy_minimal_proxy_create2_pre_endowment
Deploy a bobcat-proxy minimal proxy for the implementation address provided.
deploy_minimal_proxy_endowment
Deploy a bobcat-proxy minimal proxy for the implementation address provided.
deploy_multi3_proxy
Deploy a multi3 proxy for the implementations provided. Read bobcat-proxy for context. TLDR: we select a proxy based on the first byte in the selector.
deploy_multi3_proxy_create2
Deploy a multi3 proxy for the implementations provided. Read bobcat-proxy for context. TLDR: we select a proxy based on the first byte in the selector.
deploy_multi3_proxy_create2_endowment
Deploy a multi3 proxy for the implementations provided. Read bobcat-proxy for context. TLDR: we select a proxy based on the first byte in the selector.
deploy_multi3_proxy_create2_pre
Deploy a multi3 proxy for the implementations provided. Read bobcat-proxy for context. TLDR: we select a proxy based on the first byte in the selector.
deploy_multi3_proxy_create2_pre_endowment
Deploy a multi3 proxy for the implementations provided. Read bobcat-proxy for context. TLDR: we select a proxy based on the first byte in the selector.
deploy_multi3_proxy_endowment
Deploy a multi3 proxy for the implementations provided. Read bobcat-proxy for context. TLDR: we select a proxy based on the first byte in the selector.
deploy_upgradeable_beacon_proxy
Deploy an upgradeable beacon proxy for the beacon provided.
deploy_upgradeable_beacon_proxy_create2
Deploy an upgradeable beacon proxy for the beacon provided.
deploy_upgradeable_beacon_proxy_create2_endowment
Deploy an upgradeable beacon proxy for the beacon provided.
deploy_upgradeable_beacon_proxy_create2_pre
Deploy an upgradeable beacon proxy for the beacon provided.
deploy_upgradeable_beacon_proxy_create2_pre_endowment
Deploy an upgradeable beacon proxy for the beacon provided.
deploy_upgradeable_beacon_proxy_endowment
Deploy an upgradeable beacon proxy for the beacon provided.
estimate_addr
estimate_addr_pre
Estimate the address of the create2 deployment.