deploy_beacon_sel_proxy_sel_create2

Function deploy_beacon_sel_proxy_sel_create2 

pub fn deploy_beacon_sel_proxy_sel_create2(
    sel: [u8; 4],
    beacon: [u8; 20],
    salt: U,
) -> [u8; 20]
Create a proxy that calls the selector on the beacon proxy to figure out how to delegate the calldata to.