Structs
Functions
- const_
estimate_ addr_ post - Estimate the address of the create2 deployment.
- const_
estimate_ addr_ pre - create1_
partial - create1_
slice - create1_
slice_ res - create1_
unit - create1_
vec - create2_
partial - create2_
post_ unit - create2_
post_ vec - create2_
pre_ unit - create2_
pre_ vec - create2_
slice - create2_
slice_ pre_ keccak256 - create2_
slice_ res - create2_
vec_ pre_ keccak256 - deploy_
beacon_ proxy - Deploy a bobcat-proxy beacon proxy for the beacon provided.
- deploy_
beacon_ proxy_ create2 - Deploy a bobcat-proxy beacon proxy for the beacon provided.
- deploy_
beacon_ proxy_ create2_ endowment - Deploy a bobcat-proxy beacon proxy for the beacon provided.
- deploy_
beacon_ proxy_ create2_ pre_ endowment - Deploy a bobcat-proxy beacon proxy for the beacon provided.
- deploy_
beacon_ proxy_ endowment - Deploy a bobcat-proxy beacon proxy for the beacon provided.
- deploy_
beacon_ sel_ proxy_ sel - Create a proxy that calls the selector on the beacon proxy to figure out how to delegate the calldata to.
- deploy_
beacon_ sel_ proxy_ sel_ create2 - Create a proxy that calls the selector on the beacon proxy to figure out how to delegate the calldata to.
- deploy_
beacon_ sel_ proxy_ sel_ create2_ endowment - Create a proxy that calls the selector on the beacon proxy to figure out how to delegate the calldata to.
- deploy_
beacon_ sel_ proxy_ sel_ create2_ pre - Create a proxy that calls the selector on the beacon proxy to figure out how to delegate the calldata to.
- deploy_
beacon_ sel_ proxy_ sel_ create2_ pre_ endowment - Create a proxy that calls the selector on the beacon proxy to figure out how to delegate the calldata to.
- deploy_
beacon_ sel_ proxy_ sel_ endowment - Create a proxy that calls the selector on the beacon proxy to figure out how to delegate the calldata to.
- deploy_
minimal_ proxy - Deploy a bobcat-proxy minimal proxy for the implementation address provided.
- deploy_
minimal_ proxy_ create2 - Deploy a bobcat-proxy minimal proxy for the implementation address provided.
- deploy_
minimal_ proxy_ create2_ endowment - Deploy a bobcat-proxy minimal proxy for the implementation address provided.
- deploy_
minimal_ proxy_ create2_ pre_ endowment - Deploy a bobcat-proxy minimal proxy for the implementation address provided.
- deploy_
minimal_ proxy_ endowment - Deploy a bobcat-proxy minimal proxy for the implementation address provided.
- deploy_
multi3_ proxy - Deploy a multi3 proxy for the implementations provided. Read bobcat-proxy for context. TLDR: we select a proxy based on the first byte in the selector.
- deploy_
multi3_ proxy_ create2 - Deploy a multi3 proxy for the implementations provided. Read bobcat-proxy for context. TLDR: we select a proxy based on the first byte in the selector.
- deploy_
multi3_ proxy_ create2_ endowment - Deploy a multi3 proxy for the implementations provided. Read bobcat-proxy for context. TLDR: we select a proxy based on the first byte in the selector.
- deploy_
multi3_ proxy_ create2_ pre - Deploy a multi3 proxy for the implementations provided. Read bobcat-proxy for context. TLDR: we select a proxy based on the first byte in the selector.
- deploy_
multi3_ proxy_ create2_ pre_ endowment - Deploy a multi3 proxy for the implementations provided. Read bobcat-proxy for context. TLDR: we select a proxy based on the first byte in the selector.
- deploy_
multi3_ proxy_ endowment - Deploy a multi3 proxy for the implementations provided. Read bobcat-proxy for context. TLDR: we select a proxy based on the first byte in the selector.
- deploy_
upgradeable_ beacon_ proxy - Deploy an upgradeable beacon proxy for the beacon provided.
- deploy_
upgradeable_ beacon_ proxy_ create2 - Deploy an upgradeable beacon proxy for the beacon provided.
- deploy_
upgradeable_ beacon_ proxy_ create2_ endowment - Deploy an upgradeable beacon proxy for the beacon provided.
- deploy_
upgradeable_ beacon_ proxy_ create2_ pre - Deploy an upgradeable beacon proxy for the beacon provided.
- deploy_
upgradeable_ beacon_ proxy_ create2_ pre_ endowment - Deploy an upgradeable beacon proxy for the beacon provided.
- deploy_
upgradeable_ beacon_ proxy_ endowment - Deploy an upgradeable beacon proxy for the beacon provided.
- estimate_
addr - estimate_
addr_ pre - Estimate the address of the create2 deployment.